Mathematics
~~~~~~~~~~~

* :ref:`spkg_brial`
* :ref:`spkg_cddlib`
* :ref:`spkg_cliquer`
* :ref:`spkg_conway_polynomials`
* :ref:`spkg_cvxopt`
* :ref:`spkg_eclib`
* :ref:`spkg_ecm`
* :ref:`spkg_elliptic_curves`
* :ref:`spkg_fflas_ffpack`
* :ref:`spkg_flint`
* :ref:`spkg_fplll`
* :ref:`spkg_fpylll`
* :ref:`spkg_gap`
* :ref:`spkg_gf2x`
* :ref:`spkg_givaro`
* :ref:`spkg_glpk`
* :ref:`spkg_gmp`
* :ref:`spkg_gmpy2`
* :ref:`spkg_graphs`
* :ref:`spkg_gsl`
* :ref:`spkg_iml`
* :ref:`spkg_lcalc`
* :ref:`spkg_libbraiding`
* :ref:`spkg_libhomfly`
* :ref:`spkg_linbox`
* :ref:`spkg_lrcalc`
* :ref:`spkg_lrcalc_python`
* :ref:`spkg_m4ri`
* :ref:`spkg_m4rie`
* :ref:`spkg_maxima`
* :ref:`spkg_mpc`
* :ref:`spkg_mpfi`
* :ref:`spkg_mpfr`
* :ref:`spkg_mpmath`
* :ref:`spkg_nauty`
* :ref:`spkg_networkx`
* :ref:`spkg_ntl`
* :ref:`spkg_numpy`
* :ref:`spkg_openblas`
* :ref:`spkg_palp`
* :ref:`spkg_pari`
* :ref:`spkg_pari_galdata`
* :ref:`spkg_pari_seadata_small`
* :ref:`spkg_planarity`
* :ref:`spkg_polytopes_db`
* :ref:`spkg_ppl`
* :ref:`spkg_pplpy`
* :ref:`spkg_primecount`
* :ref:`spkg_primecountpy`
* :ref:`spkg_primesieve`
* :ref:`spkg_qhull`
* :ref:`spkg_rpy2`
* :ref:`spkg_rw`
* :ref:`spkg_scipy`
* :ref:`spkg_singular`
* :ref:`spkg_suitesparse`
* :ref:`spkg_symmetrica`
* :ref:`spkg_sympow`
* :ref:`spkg_sympy`

Front-end, graphics, document preparation
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

* :ref:`spkg_ipympl`
* :ref:`spkg_ipython`
* :ref:`spkg_ipywidgets`
* :ref:`spkg_jupyterlab`
* :ref:`spkg_jupyterlab_widgets`
* :ref:`spkg_matplotlib`
* :ref:`spkg_matplotlib_inline`
* :ref:`spkg_nbconvert`
* :ref:`spkg_notebook`
* :ref:`spkg_sagenb_export`
* :ref:`spkg_sagetex`
* :ref:`spkg_tachyon`
* :ref:`spkg_threejs`

Other dependencies
~~~~~~~~~~~~~~~~~~

* :ref:`spkg__prereq`
* :ref:`spkg_alabaster`
* :ref:`spkg_anyio`
* :ref:`spkg_appdirs`
* :ref:`spkg_appnope`
* :ref:`spkg_argon2_cffi`
* :ref:`spkg_argon2_cffi_bindings`
* :ref:`spkg_arrow`
* :ref:`spkg_asttokens`
* :ref:`spkg_async_lru`
* :ref:`spkg_attrs`
* :ref:`spkg_babel`
* :ref:`spkg_beautifulsoup4`
* :ref:`spkg_beniget`
* :ref:`spkg_bleach`
* :ref:`spkg_boost_cropped`
* :ref:`spkg_bzip2`
* :ref:`spkg_cachetools`
* :ref:`spkg_calver`
* :ref:`spkg_certifi`
* :ref:`spkg_cffi`
* :ref:`spkg_chardet`
* :ref:`spkg_charset_normalizer`
* :ref:`spkg_cmake`
* :ref:`spkg_colorama`
* :ref:`spkg_comm`
* :ref:`spkg_contourpy`
* :ref:`spkg_cppy`
* :ref:`spkg_curl`
* :ref:`spkg_cycler`
* :ref:`spkg_cysignals`
* :ref:`spkg_cython`
* :ref:`spkg_dateutil`
* :ref:`spkg_debugpy`
* :ref:`spkg_decorator`
* :ref:`spkg_defusedxml`
* :ref:`spkg_distlib`
* :ref:`spkg_docutils`
* :ref:`spkg_ecl`
* :ref:`spkg_editables`
* :ref:`spkg_entrypoints`
* :ref:`spkg_exceptiongroup`
* :ref:`spkg_execnet`
* :ref:`spkg_executing`
* :ref:`spkg_fastjsonschema`
* :ref:`spkg_filelock`
* :ref:`spkg_flex`
* :ref:`spkg_flit_core`
* :ref:`spkg_fonttools`
* :ref:`spkg_fqdn`
* :ref:`spkg_freetype`
* :ref:`spkg_furo`
* :ref:`spkg_gast`
* :ref:`spkg_gc`
* :ref:`spkg_gcc`
* :ref:`spkg_gengetopt`
* :ref:`spkg_gfortran`
* :ref:`spkg_gnulib`
* :ref:`spkg_gnumake_tokenpool`
* :ref:`spkg_h11`
* :ref:`spkg_hatchling`
* :ref:`spkg_httpcore`
* :ref:`spkg_httpx`
* :ref:`spkg_iconv`
* :ref:`spkg_idna`
* :ref:`spkg_imagesize`
* :ref:`spkg_importlib_metadata`
* :ref:`spkg_importlib_resources`
* :ref:`spkg_info`
* :ref:`spkg_iniconfig`
* :ref:`spkg_ipykernel`
* :ref:`spkg_ipython_genutils`
* :ref:`spkg_isoduration`
* :ref:`spkg_jedi`
* :ref:`spkg_jinja2`
* :ref:`spkg_json5`
* :ref:`spkg_jsonpointer`
* :ref:`spkg_jsonschema`
* :ref:`spkg_jsonschema_specifications`
* :ref:`spkg_jupyter_client`
* :ref:`spkg_jupyter_core`
* :ref:`spkg_jupyter_events`
* :ref:`spkg_jupyter_lsp`
* :ref:`spkg_jupyter_server`
* :ref:`spkg_jupyter_server_terminals`
* :ref:`spkg_jupyter_sphinx`
* :ref:`spkg_jupyterlab_mathjax2`
* :ref:`spkg_jupyterlab_pygments`
* :ref:`spkg_jupyterlab_server`
* :ref:`spkg_kiwisolver`
* :ref:`spkg_libatomic_ops`
* :ref:`spkg_libffi`
* :ref:`spkg_libgd`
* :ref:`spkg_liblzma`
* :ref:`spkg_libpng`
* :ref:`spkg_markupsafe`
* :ref:`spkg_mathjax`
* :ref:`spkg_memory_allocator`
* :ref:`spkg_meson`
* :ref:`spkg_meson_python`
* :ref:`spkg_mistune`
* :ref:`spkg_nbclient`
* :ref:`spkg_nbformat`
* :ref:`spkg_ncurses`
* :ref:`spkg_nest_asyncio`
* :ref:`spkg_ninja_build`
* :ref:`spkg_notebook_shim`
* :ref:`spkg_openssl`
* :ref:`spkg_overrides`
* :ref:`spkg_packaging`
* :ref:`spkg_pandocfilters`
* :ref:`spkg_parso`
* :ref:`spkg_patch`
* :ref:`spkg_patchelf`
* :ref:`spkg_pathspec`
* :ref:`spkg_pexpect`
* :ref:`spkg_pickleshare`
* :ref:`spkg_pillow`
* :ref:`spkg_pip`
* :ref:`spkg_pkgconf`
* :ref:`spkg_pkgconfig`
* :ref:`spkg_platformdirs`
* :ref:`spkg_pluggy`
* :ref:`spkg_ply`
* :ref:`spkg_pplpy_doc`
* :ref:`spkg_prometheus_client`
* :ref:`spkg_prompt_toolkit`
* :ref:`spkg_psutil`
* :ref:`spkg_ptyprocess`
* :ref:`spkg_pure_eval`
* :ref:`spkg_py`
* :ref:`spkg_pybind11`
* :ref:`spkg_pycparser`
* :ref:`spkg_pygments`
* :ref:`spkg_pyparsing`
* :ref:`spkg_pyproject_api`
* :ref:`spkg_pyproject_hooks`
* :ref:`spkg_pyproject_metadata`
* :ref:`spkg_pytest`
* :ref:`spkg_pytest_mock`
* :ref:`spkg_pytest_xdist`
* :ref:`spkg_python3`
* :ref:`spkg_python_build`
* :ref:`spkg_python_json_logger`
* :ref:`spkg_pythran`
* :ref:`spkg_pytz`
* :ref:`spkg_pytz_deprecation_shim`
* :ref:`spkg_pyyaml`
* :ref:`spkg_pyzmq`
* :ref:`spkg_readline`
* :ref:`spkg_referencing`
* :ref:`spkg_requests`
* :ref:`spkg_rfc3339_validator`
* :ref:`spkg_rfc3986_validator`
* :ref:`spkg_rpds_py`
* :ref:`spkg_sage_conf`
* :ref:`spkg_sage_docbuild`
* :ref:`spkg_sage_setup`
* :ref:`spkg_sagelib`
* :ref:`spkg_scikit_build_core`
* :ref:`spkg_send2trash`
* :ref:`spkg_setuptools`
* :ref:`spkg_setuptools_scm`
* :ref:`spkg_six`
* :ref:`spkg_sniffio`
* :ref:`spkg_snowballstemmer`
* :ref:`spkg_soupsieve`
* :ref:`spkg_sphinx`
* :ref:`spkg_sphinx_basic_ng`
* :ref:`spkg_sphinx_copybutton`
* :ref:`spkg_sphinx_inline_tabs`
* :ref:`spkg_sphinxcontrib_applehelp`
* :ref:`spkg_sphinxcontrib_devhelp`
* :ref:`spkg_sphinxcontrib_htmlhelp`
* :ref:`spkg_sphinxcontrib_jsmath`
* :ref:`spkg_sphinxcontrib_qthelp`
* :ref:`spkg_sphinxcontrib_serializinghtml`
* :ref:`spkg_sphinxcontrib_websupport`
* :ref:`spkg_sqlite`
* :ref:`spkg_stack_data`
* :ref:`spkg_terminado`
* :ref:`spkg_tinycss2`
* :ref:`spkg_tomli`
* :ref:`spkg_tornado`
* :ref:`spkg_tox`
* :ref:`spkg_traitlets`
* :ref:`spkg_trove_classifiers`
* :ref:`spkg_types_python_dateutil`
* :ref:`spkg_typing_extensions`
* :ref:`spkg_tzdata`
* :ref:`spkg_tzlocal`
* :ref:`spkg_uri_template`
* :ref:`spkg_urllib3`
* :ref:`spkg_virtualenv`
* :ref:`spkg_wcwidth`
* :ref:`spkg_webcolors`
* :ref:`spkg_webencodings`
* :ref:`spkg_websocket_client`
* :ref:`spkg_wheel`
* :ref:`spkg_widgetsnbextension`
* :ref:`spkg_xz`
* :ref:`spkg_zeromq`
* :ref:`spkg_zipp`
* :ref:`spkg_zlib`
